#!/usr/bin/env python3
"""
   utils.boxes.app_boxes.py file for the c3buttons system.
"""

###
### DEPENDENCIES
###
import sys
from signal import pause

### LOCAL
try:
    from utils.configuration.app_logger import set_logger_from_config
except ImportError as e:
    print("Unable to import 'setup_logger' from 'utils.configuration.app_logger.py' file at 'utils.database.app_database.py' file")
    sys.exit(1)

try:
    from .box_led import BoxLed
except ImportError as e:
    print("Unable to import 'BoxLed' from 'utils.boxes.box_led.py' file at 'utils.boxes.app_boxes.py' file" )
    sys.exit(1)

try:
    from .box_button import BoxButton
except ImportError as e:
    print("Unable to import 'BoxButton' from 'utils.boxes.box_button.py' file at 'utils.boxes.app_boxes.py' file" )
    sys.exit(1)


class AppBoxes():
    """
        Class for setting the Boxes of the app.
    """

    def __init__(self, configuration: object, database: object) -> None:
        """
            Function for initialiazing the AppConfiguration class.
            Sets the class variables.

            Returns
            -------
            None
        """

        self.configuration = configuration
        self.database = database

        self.logger = set_logger_from_config(name=__name__, config=self.configuration)

        self.buttons = {}
        self.set_boxes()
        self.set_button_functions()

    def set_boxes(self):

        self.logger.debug("set_boxes")

        for box_name in self.configuration.boxes_used:
            if self.configuration.boxes.get(box_name) is not None:
                box_info = self.configuration.boxes.get(box_name)
                if box_info.get('pin_button') is None:
                    print(f"\n\n The 'pin_button' value for box with name '{box_name}' was not set" )
                    sys.exit(1)

                if box_info.get('pin_led') is None:
                    print(f"\n\n The 'pin_led' value for box with name '{box_name}' was not set" )
                    sys.exit(1)

                box_led = None
                if self.configuration.box_led_enabled:
                    box_led = BoxLed(
                        configuration=self.configuration,
                        box_name=box_name,
                    )

                box_button = BoxButton(
                    configuration=self.configuration,
                    box_name=box_name,
                    database=self.database,
                    box_led=box_led,
                )

                self.buttons[box_name] = box_button

    def set_button_functions(self):

        self.logger.debug("set_button_functions")

        try:
            for btn_name, btn in self.buttons.items():
                btn.button.when_pressed = btn.activated
                self.logger.debug(f"Button functions for box: '{btn_name}' activated...")

            pause()
        finally:
            pass
