#!/usr/bin/env python3
"""
   utils.configuration.from_file_yaml.py file for the c3 buttons.
"""

###
### DEPENDENCIES
###
import sys
import json

try:
    import pyaml_env
except ImportError as e:
    print("Unable to import 'pyaml_env'")
    print("Please install it with 'pip(3) install pyaml_env --user'")
    sys.exit(1)

### LOCAL
try:
    from .from_file import ConfigurationFromFile
except ImportError as e:
    print("Unable to import 'ConfigurationFromFile' from 'utils.configuration.from_file.py' file at the 'utils.configuration.from_file_yaml.py' file" )
    sys.exit(1)


class ConfigurationFromYamlFile(ConfigurationFromFile):

    def __init__(self, default_values: dict) -> None:

        ### Init super
        super().__init__(name=__name__, default_values=default_values)

        self.path_config_file = self.default_values.get('DEFAULT_PATH_CONFIG_YML')
        self.dict_values = self.get_values()

    def __get_env_dict__(self, parsed: dict) -> dict:

        self.logger.debug(f"__get_env_dict__ - {parsed}")

        parsed['boxes_used'] = parsed.get("boxes_used").replace(' ',''). split(',')
        parsed['boxes'] = {}

        for box_name in parsed.get("boxes_used"):

            box_info = parsed.get(box_name)
            if box_info is None:
                print(f"\n\n Error getting the configuration from the box '{box_name}' from the 'config.yml' file. \n If you want to use this box, configure it also.\n\n")
                sys.exit(1)

            if isinstance(box_info, dict):
                ret_dict = box_info

            else:
                try:
                    ret_dict = json.loads(box_info)

                except Exception as e:
                    print(f"\n\n Unable to parse the dictionary from the '{box_name}' with value: '{box_info}' \n| The exception is: '{e}' \n\n")
                    sys.exit(1)

            parsed["boxes"][box_name.lower()] = ret_dict
            parsed.pop(box_name)

        return parsed

    def get_values(self) -> dict:

        self.logger.debug(f"get_values")

        try:
            parsed_all = pyaml_env.parse_config(self.path_config_file)

        except Exception as e:
            print(f"\n\n Error reading the 'yaml' configurtion file. \n Exception: {e}")
            sys.exit(1)

        default_parsed = parsed_all.get('default')
        if default_parsed is None:
            print(f"\n\n Error getting the configuration from the 'config.yml' file. \n Exception: {e}")
            sys.exit(1)

        return self.__get_env_dict__(parsed=default_parsed)
